@@ -63,19 +63,20 @@ class AkinonCloudClient:
         if self.token:
             headers["Authorization"] = f"Token {self.token}"
         url = f"{self.URLS['base']}{self.URLS[url]}".format(**params)
-        response = requests.request(method=method, url=url, json=data,
-                                    headers=headers, params=qs)
+        response = requests.request(method=method, url=url, json=data, headers=headers, params=qs)
         if response.status_code >= 500:
             raise AkinonCLIError("An error has occurred on our side. We'll fix that.", response=response)
         elif response.status_code == 401:
             raise AkinonCLIError("Unauthenticated request, please log in with your credentials.", response=response)
         elif response.status_code == 403:
-            raise AkinonCLIError("You do not have access to do this action. Please contact your account owner.",
-                                 response=response)
+            raise AkinonCLIError(
+                "You do not have access to do this action. Please contact your account owner.", response=response
+            )
         elif not response.ok:
             raise AkinonCLIError(
                 f'API returned an unsuccessful status code. HTTP {response.status_code}: {response.reason}',
-                response=response)
+                response=response,
+            )
 
         data = response.content
         if response_format == 'json':
@@ -84,9 +85,7 @@ class AkinonCloudClient:
             except json.decoder.JSONDecodeError:
                 data = {}
 
-        return AkinonResponse(is_succeed=response.ok,
-                              status_code=response.status_code,
-                              data=data)
+        return AkinonResponse(is_succeed=response.ok, status_code=response.status_code, data=data)
 
     def login(self, data):
         return self._send_request("POST", "login", data=data)
@@ -101,8 +100,7 @@ class AkinonCloudClient:
         return self._send_request("POST", "projects", data=data)
 
     def update_project(self, p_id, data):
-        response = self._send_request("PATCH", "project_detail", params={"p_id": p_id},
-                                      data=data)
+        response = self._send_request("PATCH", "project_detail", params={"p_id": p_id}, data=data)
         if response.status_code == 404:
             raise AkinonCLIError("Project could not found.")
         return response
@@ -123,15 +121,13 @@ class AkinonCloudClient:
         return self._send_request("POST", "apps", data=data)
 
     def update_application(self, app_id, data):
-        response = self._send_request("PATCH", "app_detail", params={"app_id": app_id},
-                                      data=data)
+        response = self._send_request("PATCH", "app_detail", params={"app_id": app_id}, data=data)
         if response.status_code == 404:
             raise AkinonCLIError("Application could not found.")
         return response
 
     def build_application(self, app_id, data):
-        response = self._send_request("POST", "app_build", params={"app_id": app_id},
-                                      data=data)
+        response = self._send_request("POST", "app_build", params={"app_id": app_id}, data=data)
         if response.status_code == 404:
             raise AkinonCLIError("Application could not found.")
         return response
@@ -146,8 +142,7 @@ class AkinonCloudClient:
         return self._send_request("GET", "app_users", params={"app_id": app_id})
 
     def create_app_user(self, app_id, data):
-        return self._send_request("POST", "app_users", params={"app_id": app_id},
-                                  data=data)
+        return self._send_request("POST", "app_users", params={"app_id": app_id}, data=data)
 
     def get_application_types(self, qs: dict):
         return self._send_request("GET", "application_types", qs=qs)
@@ -156,19 +151,18 @@ class AkinonCloudClient:
         return self._send_request("GET", "project_apps", params={"p_id": p_id}, qs=qs)
 
     def get_project_app(self, p_id, pa_id):
-        return self._send_request("GET", "project_app_detail", params={"p_id": p_id,
-                                                                       "pa_id": pa_id})
+        return self._send_request("GET", "project_app_detail", params={"p_id": p_id, "pa_id": pa_id})
 
     def update_project_app(self, p_id, pa_id, data):
-        response = self._send_request("PATCH", "project_app_detail", params={"p_id": p_id, "pa_id": pa_id},
-                                      data=data)
+        response = self._send_request("PATCH", "project_app_detail", params={"p_id": p_id, "pa_id": pa_id}, data=data)
         if response.status_code == 404:
             raise AkinonCLIError("Project App could not found.")
         return response
 
     def delete_project_app_custom_env(self, p_id, pa_id, data):
-        response = self._send_request("POST", "project_app_custom_env", params={"p_id": p_id, "pa_id": pa_id},
-                                      data=data)
+        response = self._send_request(
+            "POST", "project_app_custom_env", params={"p_id": p_id, "pa_id": pa_id}, data=data
+        )
         if response.status_code == 404:
             raise AkinonCLIError("Project App could not found.")
         return response
@@ -180,12 +174,13 @@ class AkinonCloudClient:
         return response
 
     def get_project_app_logs(self, project_id, project_app_id, data):
-        return self._send_request("POST", "project_apps_logs",
-                                  params={"project_id": project_id, "project_app_id": project_app_id},
-                                  data=data)
+        return self._send_request(
+            "POST", "project_apps_logs", params={"project_id": project_id, "project_app_id": project_app_id}, data=data
+        )
 
-    def export_project_app_logs(self, project_id, project_app_id, start_date=None, end_date=None, dates=None,
-                                applications=None):
+    def export_project_app_logs(
+        self, project_id, project_app_id, start_date=None, end_date=None, dates=None, applications=None
+    ):
         data = {}
 
         if start_date:
@@ -200,13 +195,15 @@ class AkinonCloudClient:
         if applications:
             data['applications'] = applications.split(',')
 
-        return self._send_request('POST', 'project_apps_export_logs',
-                                  params={"project_id": project_id, "project_app_id": project_app_id},
-                                  data=data)
+        return self._send_request(
+            'POST',
+            'project_apps_export_logs',
+            params={"project_id": project_id, "project_app_id": project_app_id},
+            data=data,
+        )
 
     def create_project_app(self, p_id, data):
-        return self._send_request("POST", "project_apps", params={"p_id": p_id},
-                                  data=data)
+        return self._send_request("POST", "project_apps", params={"p_id": p_id}, data=data)
 
     def deploy_project_app(self, p_id: int, pa_id: int, data: dict) -> AkinonResponse:
         response = self._send_request(
@@ -216,7 +213,7 @@ class AkinonCloudClient:
                 "p_id": p_id,
                 "pa_id": pa_id,
             },
-            data=data
+            data=data,
         )
         if response.status_code == 404:
             raise AkinonCLIError("Project App could not be found.")
@@ -229,20 +226,19 @@ class AkinonCloudClient:
             params={
                 "app_id": app_id,
             },
-            data=data
+            data=data,
         )
         if response.status_code == 404:
             raise AkinonCLIError("App could not be found.")
         return response
 
     def get_project_app_deployments(self, p_id, pa_id):
-        return self._send_request("GET", "project_app_deployments", params={"p_id": p_id,
-                                                                            "pa_id": pa_id})
+        return self._send_request("GET", "project_app_deployments", params={"p_id": p_id, "pa_id": pa_id})
 
     def get_project_app_deployment_logs(self, p_id, pa_id, deployment_id):
-        return self._send_request("GET", "project_app_deployment_log", params={"p_id": p_id,
-                                                                               "pa_id": pa_id,
-                                                                               "deployment_id": deployment_id})
+        return self._send_request(
+            "GET", "project_app_deployment_log", params={"p_id": p_id, "pa_id": pa_id, "deployment_id": deployment_id}
+        )
 
     def get_public_keys(self, qs: dict):
         return self._send_request("GET", "public_keys", qs=qs)
@@ -273,12 +269,10 @@ class AkinonCloudClient:
         return self._send_request("POST", "domains", data=data)
 
     def get_certificates(self, domain_id, qs: dict):
-        return self._send_request("GET", "certificates",
-                                  params={"domain_id": domain_id}, qs=qs)
+        return self._send_request("GET", "certificates", params={"domain_id": domain_id}, qs=qs)
 
     def create_certificate(self, domain_id, data):
-        return self._send_request("POST", "certificates", data=data,
-                                  params={'domain_id': domain_id})
+        return self._send_request("POST", "certificates", data=data, params={'domain_id': domain_id})
 
     def get_addons(self, project_id: int, project_app_id: int):
         return self._send_request(
