@@ -3,14 +3,16 @@ import textwrap
 from cement import Controller, ex
 from cement.utils.version import get_version_banner
 
-from . import PaginationEnum
 from ..core.version import get_version
-
+from . import PaginationEnum
 
 VERSION_BANNER = """
 CLI for Akinon Cloud Commerce %s
 %s
-""" % (get_version(), get_version_banner())
+""" % (
+    get_version(),
+    get_version_banner(),
+)
 
 
 class Applications(Controller):
@@ -22,38 +24,40 @@ class Applications(Controller):
 
     @ex(
         help='Application List Command',
-        arguments=[
-            PaginationEnum.ARG
-        ],
+        arguments=[PaginationEnum.ARG],
     )
     def list(self):
-        response = self.app.client.get_applications(
-            qs={"page": getattr(self.app.pargs, PaginationEnum.KEY)}
-        )
+        response = self.app.client.get_applications(qs={"page": getattr(self.app.pargs, PaginationEnum.KEY)})
         results = []
         for result in response.data.get("results", []):
             application_type_data = result["application_type"]
             result['application_type_slug'] = application_type_data["slug"] if application_type_data else ""
             results.append(result)
-        self.app.render(data=response.data, rows=results,
-                        headers={
-                            'pk': 'ID',
-                            'slug': 'Slug',
-                            'name': 'Name',
-                            'is_private': 'Private',
-                            'status': 'Status',
-                            'application_type_slug': 'Type'
-                        },
-                        is_succeed=response.is_succeed)
+        self.app.render(
+            data=response.data,
+            rows=results,
+            headers={
+                'pk': 'ID',
+                'slug': 'Slug',
+                'name': 'Name',
+                'is_private': 'Private',
+                'status': 'Status',
+                'application_type_slug': 'Type',
+            },
+            is_succeed=response.is_succeed,
+        )
 
     @ex(
         help='Application Get Command',
         arguments=[
-            (['app_id'], {
-                'help': 'Application ID',
-                'action': 'store',
-            }),
-        ]
+            (
+                ['app_id'],
+                {
+                    'help': 'Application ID',
+                    'action': 'store',
+                },
+            ),
+        ],
     )
     def get(self):
         result = self.app.client.get_application(
@@ -61,33 +65,46 @@ class Applications(Controller):
         ).data
         application_type_data = result["application_type"]
         result['application_type_slug'] = application_type_data["slug"] if application_type_data else ""
-        formatted = textwrap.dedent(f'''
+        formatted = textwrap.dedent(
+            f'''
             [b]Name[/b]: {result["name"]}
             [b]Slug[/b]: {result["slug"]}
             [b]Type[/b]: {result["application_type_slug"]}
             [b]Status[/b]: {result["status"]}
             [b]Private[/b]: {result["is_private"]}
             [b]Clone URL[/b]: {result['clone_url']}
-        '''.strip('\n'))
+        '''.strip(
+                '\n'
+            )
+        )
 
         self.app.render(formatted, renderer_type='rich', is_succeed=True, soft_wrap=True)
 
     @ex(
         help='Application Create Command',
         arguments=[
-            (['name'], {
-                'help': 'Application name',
-                'action': 'store',
-            }),
-            (['slug'], {
-                'help': 'Application slug',
-                'action': 'store',
-            }),
-            (['application_type_id'], {
-                'help': 'Application type id',
-                'action': 'store',
-            }),
-        ]
+            (
+                ['name'],
+                {
+                    'help': 'Application name',
+                    'action': 'store',
+                },
+            ),
+            (
+                ['slug'],
+                {
+                    'help': 'Application slug',
+                    'action': 'store',
+                },
+            ),
+            (
+                ['application_type_id'],
+                {
+                    'help': 'Application type id',
+                    'action': 'store',
+                },
+            ),
+        ],
     )
     def create(self):
         data = {
@@ -105,19 +122,28 @@ class Applications(Controller):
     @ex(
         help='Application Update Command',
         arguments=[
-            (['id'], {
-                'help': 'Application ID',
-                'action': 'store',
-            }),
-            (['name'], {
-                'help': 'Application Name',
-                'action': 'store',
-            }),
-            (['slug'], {
-                'help': 'Application slug',
-                'action': 'store',
-            }),
-        ]
+            (
+                ['id'],
+                {
+                    'help': 'Application ID',
+                    'action': 'store',
+                },
+            ),
+            (
+                ['name'],
+                {
+                    'help': 'Application Name',
+                    'action': 'store',
+                },
+            ),
+            (
+                ['slug'],
+                {
+                    'help': 'Application slug',
+                    'action': 'store',
+                },
+            ),
+        ],
     )
     def update(self):
         app_id = self.app.pargs.id
@@ -134,19 +160,22 @@ class Applications(Controller):
     @ex(
         help='Application Build Command',
         arguments=[
-            (['id'], {
-                'help': 'Application ID',
-                'action': 'store',
-            }),
-            (['tag'], {
-                'help': 'App Version',
-                'action': 'store',
-            }),
-            (['--note'], {
-                'help': 'Version Note',
-                'action': 'store'
-            })
-        ]
+            (
+                ['id'],
+                {
+                    'help': 'Application ID',
+                    'action': 'store',
+                },
+            ),
+            (
+                ['tag'],
+                {
+                    'help': 'App Version',
+                    'action': 'store',
+                },
+            ),
+            (['--note'], {'help': 'Version Note', 'action': 'store'}),
+        ],
     )
     def build(self):
         app_id = self.app.pargs.id
@@ -163,29 +192,23 @@ class Applications(Controller):
 
     @ex(
         help='Application Version List Command',
-        arguments=[
-            (['id'], {
-                'help': 'Application ID',
-                'action': 'store'
-            })
-        ],
+        arguments=[(['id'], {'help': 'Application ID', 'action': 'store'})],
     )
     def versions(self):
         app_id = self.app.pargs.id
         response = self.app.client.get_app_versions(app_id)
-        self.app.render(data=response.data, rows=response.data.get('results', []),
-                        headers={'pk': 'ID', 'app': 'App', 'tag': 'Tag',
-                                 'status': 'Status', 'created_date': 'CreatedDate'},
-                        is_succeed=response.is_succeed)
+        self.app.render(
+            data=response.data,
+            rows=response.data.get('results', []),
+            headers={'pk': 'ID', 'app': 'App', 'tag': 'Tag', 'status': 'Status', 'created_date': 'CreatedDate'},
+            is_succeed=response.is_succeed,
+        )
 
     @ex(
         help='Application Version Log List Command',
         arguments=[
-            (['id'], {
-                'help': 'Application ID',
-                'action': 'store'
-            }),
-            (['version_id'], {'help': 'Version ID', 'action': 'store'})
+            (['id'], {'help': 'Application ID', 'action': 'store'}),
+            (['version_id'], {'help': 'Version ID', 'action': 'store'}),
         ],
     )
     def version_logs(self):
@@ -206,15 +229,20 @@ class ApplicationTypes(Controller):
 
     @ex(
         help='Application Type List Command',
-        arguments=[
-            PaginationEnum.ARG
-        ],
+        arguments=[PaginationEnum.ARG],
     )
     def list(self):
         qs = {"is_visible_on_app_creation": True, "page": getattr(self.app.pargs, PaginationEnum.KEY)}
         response = self.app.client.get_application_types(qs=qs)
-        self.app.render(data=response.data, rows=response.data.get('results', []),
-                        headers={'pk': 'ID', 'slug': 'Slug', 'name': 'Name',
-                                 'created_date': 'Created Date',
-                                 'update_date': 'Updated Date'},
-                        is_succeed=response.is_succeed)
+        self.app.render(
+            data=response.data,
+            rows=response.data.get('results', []),
+            headers={
+                'pk': 'ID',
+                'slug': 'Slug',
+                'name': 'Name',
+                'created_date': 'Created Date',
+                'update_date': 'Updated Date',
+            },
+            is_succeed=response.is_succeed,
+        )
