@@ -1,17 +1,20 @@
 import os
-from datetime import datetime, timezone, timedelta
+from datetime import datetime, timedelta, timezone
 
 from cement import Controller, ex
 from cement.utils.version import get_version_banner
 
 from ..core.exc import AkinonCLIError, AkinonCLIWarning
-from . import PaginationEnum
 from ..core.version import get_version
+from . import PaginationEnum
 
 VERSION_BANNER = """
 CLI for Akinon Cloud Commerce %s
 %s
-""" % (get_version(), get_version_banner())
+""" % (
+    get_version(),
+    get_version_banner(),
+)
 
 
 class Projects(Controller):
@@ -23,40 +26,51 @@ class Projects(Controller):
 
     @ex(
         help='Project List Command',
-        arguments=[
-            PaginationEnum.ARG
-        ],
+        arguments=[PaginationEnum.ARG],
     )
     def list(self):
-        response = self.app.client.get_projects(
-            qs={"page": getattr(self.app.pargs, PaginationEnum.KEY)}
+        response = self.app.client.get_projects(qs={"page": getattr(self.app.pargs, PaginationEnum.KEY)})
+        self.app.render(
+            data=response.data,
+            rows=response.data.get('results', []),
+            headers={'pk': 'ID', 'slug': 'Slug', 'name': 'Name'},
+            is_succeed=response.is_succeed,
         )
-        self.app.render(data=response.data, rows=response.data.get('results', []),
-                        headers={'pk': 'ID', 'slug': 'Slug', 'name': 'Name'},
-                        is_succeed=response.is_succeed)
 
     @ex(
         help='Project Create Command',
         arguments=[
-            (['name'], {
-                'help': 'Project name',
-                'action': 'store',
-            }),
-            (['slug'], {
-                'help': 'Project slug',
-                'action': 'store',
-            }),
-            (['--mainapp-required'], {
-                'help': 'if main app is required. Choose main app required as true.',
-                'action': 'store_true',
-                'dest': 'is_main_app_required'
-            }),
-            (['--mainapp-initialize'], {
-                'help': 'Allow you to initialize main app automatically.',
-                'action': 'store_true',
-                'dest': 'initialize_main_app'
-            }),
-        ]
+            (
+                ['name'],
+                {
+                    'help': 'Project name',
+                    'action': 'store',
+                },
+            ),
+            (
+                ['slug'],
+                {
+                    'help': 'Project slug',
+                    'action': 'store',
+                },
+            ),
+            (
+                ['--mainapp-required'],
+                {
+                    'help': 'if main app is required. Choose main app required as true.',
+                    'action': 'store_true',
+                    'dest': 'is_main_app_required',
+                },
+            ),
+            (
+                ['--mainapp-initialize'],
+                {
+                    'help': 'Allow you to initialize main app automatically.',
+                    'action': 'store_true',
+                    'dest': 'initialize_main_app',
+                },
+            ),
+        ],
     )
     def create(self):
         data = {
@@ -74,15 +88,21 @@ class Projects(Controller):
     @ex(
         help='Project Update Command',
         arguments=[
-            (['id'], {
-                'help': 'Project ID',
-                'action': 'store',
-            }),
-            (['name'], {
-                'help': 'New project name',
-                'action': 'store',
-            }),
-        ]
+            (
+                ['id'],
+                {
+                    'help': 'Project ID',
+                    'action': 'store',
+                },
+            ),
+            (
+                ['name'],
+                {
+                    'help': 'New project name',
+                    'action': 'store',
+                },
+            ),
+        ],
     )
     def update(self):
         p_id = self.app.pargs.id
@@ -106,19 +126,19 @@ class ProjectApps(Controller):
     @ex(
         help='Project App List Command',
         arguments=[
-            (['project_id'], {
-                'help': 'Project ID',
-                'action': 'store',
-            }),
+            (
+                ['project_id'],
+                {
+                    'help': 'Project ID',
+                    'action': 'store',
+                },
+            ),
             PaginationEnum.ARG,
         ],
     )
     def list(self):
         p_id = self.app.pargs.project_id
-        response = self.app.client.get_project_apps(
-            p_id=p_id,
-            qs={"page": getattr(self.app.pargs, PaginationEnum.KEY)}
-        )
+        response = self.app.client.get_project_apps(p_id=p_id, qs={"page": getattr(self.app.pargs, PaginationEnum.KEY)})
         rows = response.data.get('results', [])
         for row in rows:
             row['app'] = row['app']['name']
@@ -126,28 +146,48 @@ class ProjectApps(Controller):
             row['env'] = ''
             for key, value in row['custom_env'].items():
                 row['env'] += f'{key}={value}\n'
-        self.app.render(data=response.data, rows=response.data.get('results', []),
-                        headers={'pk': 'ID', 'project': 'Project', 'app': 'App',
-                                 'url': 'URL', 'created_date': 'Created Date',
-                                 'env': 'ENV Variables'},
-                        is_succeed=response.is_succeed)
+        self.app.render(
+            data=response.data,
+            rows=response.data.get('results', []),
+            headers={
+                'pk': 'ID',
+                'project': 'Project',
+                'app': 'App',
+                'url': 'URL',
+                'created_date': 'Created Date',
+                'env': 'ENV Variables',
+            },
+            is_succeed=response.is_succeed,
+        )
 
     @ex(
         help='Project App Add or Update Environment Value Command',
         arguments=[
-            (['project_id'], {
-                'help': 'Project ID',
-                'action': 'store',
-            }),
-            (['project_app_id'], {
-                'help': 'Project App ID',
-                'action': 'store',
-            }),
-            (['env_variables'],
-             {'help':  'Environment Variables (KEY=VALUE)', 'action': 'store', 'nargs': '+'}),
-            (['--deploy'], {'help': "Redeploy the current version to activate environment variable changes.",
-                               'action': 'store_true', 'dest': 'deploy', 'default': False}),
-        ]
+            (
+                ['project_id'],
+                {
+                    'help': 'Project ID',
+                    'action': 'store',
+                },
+            ),
+            (
+                ['project_app_id'],
+                {
+                    'help': 'Project App ID',
+                    'action': 'store',
+                },
+            ),
+            (['env_variables'], {'help': 'Environment Variables (KEY=VALUE)', 'action': 'store', 'nargs': '+'}),
+            (
+                ['--deploy'],
+                {
+                    'help': "Redeploy the current version to activate environment variable changes.",
+                    'action': 'store_true',
+                    'dest': 'deploy',
+                    'default': False,
+                },
+            ),
+        ],
     )
     def add_env(self):
         p_id = self.app.pargs.project_id
@@ -169,32 +209,49 @@ class ProjectApps(Controller):
             for key, value in row['custom_env'].items():
                 row['env'] += f'{key}={value}\n'
 
-            self.app.render(data=response.data, rows=[row],
-                            headers={'pk': 'ID', 'project': 'Project', 'app': 'App',
-                                     'created_date': 'Created Date', 'env': 'ENV Variables'},
-                            is_succeed=response.is_succeed)
+            self.app.render(
+                data=response.data,
+                rows=[row],
+                headers={
+                    'pk': 'ID',
+                    'project': 'Project',
+                    'app': 'App',
+                    'created_date': 'Created Date',
+                    'env': 'ENV Variables',
+                },
+                is_succeed=response.is_succeed,
+            )
         else:
             self.app.render(response.data, renderer_type='text')
 
     @ex(
         help='Project App Remove Environment Value Command',
         arguments=[
-            (['project_id'], {
-                'help': 'Project ID',
-                'action': 'store',
-            }),
-            (['project_app_id'], {
-                'help': 'Project App ID',
-                'action': 'store',
-            }),
-            (['env_keys'], {
-                'help': 'Keys',
-                'action': 'store',
-                'nargs': '+'
-            }),
-            (['--deploy'], {'help': "Redeploy the current version to activate environment variable changes.",
-                               'action': 'store_true', 'dest': 'deploy', 'default': False}),
-        ]
+            (
+                ['project_id'],
+                {
+                    'help': 'Project ID',
+                    'action': 'store',
+                },
+            ),
+            (
+                ['project_app_id'],
+                {
+                    'help': 'Project App ID',
+                    'action': 'store',
+                },
+            ),
+            (['env_keys'], {'help': 'Keys', 'action': 'store', 'nargs': '+'}),
+            (
+                ['--deploy'],
+                {
+                    'help': "Redeploy the current version to activate environment variable changes.",
+                    'action': 'store_true',
+                    'dest': 'deploy',
+                    'default': False,
+                },
+            ),
+        ],
     )
     def remove_env(self):
         p_id = self.app.pargs.project_id
@@ -218,32 +275,44 @@ class ProjectApps(Controller):
             for key, value in row['custom_env'].items():
                 row['env'] += f'{key}={value}\n'
 
-            self.app.render(response.data, rows=[row],
-                            headers={'pk': 'ID', 'project': 'Project', 'app': 'App',
-                                     'created_date': 'Created Date', 'env': 'ENV Variables'},
-                            is_succeed=response.is_succeed)
+            self.app.render(
+                response.data,
+                rows=[row],
+                headers={
+                    'pk': 'ID',
+                    'project': 'Project',
+                    'app': 'App',
+                    'created_date': 'Created Date',
+                    'env': 'ENV Variables',
+                },
+                is_succeed=response.is_succeed,
+            )
         else:
             self.app.render(response.data, renderer_type='text')
 
     @ex(
         help='Project App Add Command',
         arguments=[
-            (['project_id'], {
-                'help': 'Project ID',
-                'action': 'store',
-            }),
-            (['app_id'], {
-                'help': 'App ID',
-                'action': 'store',
-            }),
+            (
+                ['project_id'],
+                {
+                    'help': 'Project ID',
+                    'action': 'store',
+                },
+            ),
+            (
+                ['app_id'],
+                {
+                    'help': 'App ID',
+                    'action': 'store',
+                },
+            ),
         ],
     )
     def add(self):
         p_id = self.app.pargs.project_id
         app_id = self.app.pargs.app_id
-        data = {
-            'app': app_id
-        }
+        data = {'app': app_id}
         response = self.app.client.create_project_app(p_id, data)
         if response.is_succeed:
             self.app.render("App has been added to the project.", renderer_type='text')
@@ -253,26 +322,33 @@ class ProjectApps(Controller):
     @ex(
         help='Project App Deploy Command',
         arguments=[
-            (['project_id'], {
-                'help': 'Project ID',
-                'action': 'store',
-            }),
-            (['project_app_id'], {
-                'help': 'Project App ID',
-                'action': 'store',
-            }),
-            (['tag'], {
-                'help': 'Tag',
-                'action': 'store',
-            }),
+            (
+                ['project_id'],
+                {
+                    'help': 'Project ID',
+                    'action': 'store',
+                },
+            ),
+            (
+                ['project_app_id'],
+                {
+                    'help': 'Project App ID',
+                    'action': 'store',
+                },
+            ),
+            (
+                ['tag'],
+                {
+                    'help': 'Tag',
+                    'action': 'store',
+                },
+            ),
         ],
     )
     def deploy(self):
         p_id = self.app.pargs.project_id
         pa_id = self.app.pargs.project_app_id
-        data = {
-            'tag': self.app.pargs.tag
-        }
+        data = {'tag': self.app.pargs.tag}
         response = self.app.client.deploy_project_app(p_id, pa_id, data=data)
 
         if response.is_succeed:
@@ -283,27 +359,39 @@ class ProjectApps(Controller):
     @ex(
         help='Multiple Project App Deploy Command',
         arguments=[
-            (['app_id'], {
-                'help': 'Application ID',
-                'action': 'store',
-            }),
-            (['tag'], {
-                'help': 'App Version',
-                'action': 'store',
-            }),
-            (['--project-apps'], {
-                'help': 'Project App IDs',
-                'action': 'store',
-                'nargs': '+',
-                'default': [],
-            }),
-            (['--deploy-all'], {
-                'help': "Deploys all project apps with given app_id and tag.",
-                'action': 'store_true',
-                'dest': 'deploy_all',
-                'default': False,
-            }),
-        ]
+            (
+                ['app_id'],
+                {
+                    'help': 'Application ID',
+                    'action': 'store',
+                },
+            ),
+            (
+                ['tag'],
+                {
+                    'help': 'App Version',
+                    'action': 'store',
+                },
+            ),
+            (
+                ['--project-apps'],
+                {
+                    'help': 'Project App IDs',
+                    'action': 'store',
+                    'nargs': '+',
+                    'default': [],
+                },
+            ),
+            (
+                ['--deploy-all'],
+                {
+                    'help': "Deploys all project apps with given app_id and tag.",
+                    'action': 'store_true',
+                    'dest': 'deploy_all',
+                    'default': False,
+                },
+            ),
+        ],
     )
     def deploy_multiple(self):
         data = {
@@ -320,37 +408,51 @@ class ProjectApps(Controller):
     @ex(
         help='Project App Deployment List Command',
         arguments=[
-            (['project_id'], {
-                'help': 'Project ID',
-                'action': 'store',
-            }),
-            (['project_app_id'], {
-                'help': 'Project App ID',
-                'action': 'store',
-            })
+            (
+                ['project_id'],
+                {
+                    'help': 'Project ID',
+                    'action': 'store',
+                },
+            ),
+            (
+                ['project_app_id'],
+                {
+                    'help': 'Project App ID',
+                    'action': 'store',
+                },
+            ),
         ],
     )
     def deployments(self):
         p_id = self.app.pargs.project_id
         pa_id = self.app.pargs.project_app_id
         response = self.app.client.get_project_app_deployments(p_id, pa_id)
-        self.app.render(data=response.data, rows=response.data.get('results', []),
-                        headers={'pk': 'ID', 'version': 'Version', 'status': 'Status',
-                                 'created_date': 'Created Date'},
-                        is_succeed=response.is_succeed)
+        self.app.render(
+            data=response.data,
+            rows=response.data.get('results', []),
+            headers={'pk': 'ID', 'version': 'Version', 'status': 'Status', 'created_date': 'Created Date'},
+            is_succeed=response.is_succeed,
+        )
 
     @ex(
         help='Project App Deployment Log List Command',
         arguments=[
-            (['project_id'], {
-                'help': 'Project ID',
-                'action': 'store',
-            }),
-            (['project_app_id'], {
-                'help': 'Project App ID',
-                'action': 'store',
-            }),
-            (['deployment_id'], {'help': 'Deployment ID', 'action': 'store'})
+            (
+                ['project_id'],
+                {
+                    'help': 'Project ID',
+                    'action': 'store',
+                },
+            ),
+            (
+                ['project_app_id'],
+                {
+                    'help': 'Project App ID',
+                    'action': 'store',
+                },
+            ),
+            (['deployment_id'], {'help': 'Deployment ID', 'action': 'store'}),
         ],
     )
     def deployment_logs(self):
@@ -365,26 +467,33 @@ class ProjectApps(Controller):
     @ex(
         help='Attach Certificate to Project App',
         arguments=[
-            (['project_id'], {
-                'help': 'Project ID',
-                'action': 'store',
-            }),
-            (['project_app_id'], {
-                'help': 'Project App ID',
-                'action': 'store',
-            }),
-            (['certificate_id'], {
-                'help': 'Certificate ID',
-                'action': 'store',
-            }),
+            (
+                ['project_id'],
+                {
+                    'help': 'Project ID',
+                    'action': 'store',
+                },
+            ),
+            (
+                ['project_app_id'],
+                {
+                    'help': 'Project App ID',
+                    'action': 'store',
+                },
+            ),
+            (
+                ['certificate_id'],
+                {
+                    'help': 'Certificate ID',
+                    'action': 'store',
+                },
+            ),
         ],
     )
     def attach_certificate(self):
         p_id = self.app.pargs.project_id
         pa_id = self.app.pargs.project_app_id
-        data = {
-            'certificate': self.app.pargs.certificate_id
-        }
+        data = {'certificate': self.app.pargs.certificate_id}
         response = self.app.client.update_project_app(p_id, pa_id, data=data)
 
         if response.is_succeed:
@@ -395,22 +504,26 @@ class ProjectApps(Controller):
     @ex(
         help='Detach Certificate to Project App',
         arguments=[
-            (['project_id'], {
-                'help': 'Project ID',
-                'action': 'store',
-            }),
-            (['project_app_id'], {
-                'help': 'Project App ID',
-                'action': 'store',
-            })
+            (
+                ['project_id'],
+                {
+                    'help': 'Project ID',
+                    'action': 'store',
+                },
+            ),
+            (
+                ['project_app_id'],
+                {
+                    'help': 'Project App ID',
+                    'action': 'store',
+                },
+            ),
         ],
     )
     def detach_certificate(self):
         p_id = self.app.pargs.project_id
         pa_id = self.app.pargs.project_app_id
-        data = {
-            'certificate': None
-        }
+        data = {'certificate': None}
         response = self.app.client.update_project_app(p_id, pa_id, data=data)
 
         if response.is_succeed:
@@ -421,7 +534,13 @@ class ProjectApps(Controller):
     @ex(
         help='Get Project App Logs',
         arguments=[
-            (['project_id'], {'help': 'Project ID', 'action': 'store', }),
+            (
+                ['project_id'],
+                {
+                    'help': 'Project ID',
+                    'action': 'store',
+                },
+            ),
             (['project_app_id'], {'help': 'Project App ID', 'action': 'store'}),
             (['-p', '--process'], {'help': 'Process type', 'action': 'store', 'dest': "process_type", 'default': ''}),
         ],
@@ -453,21 +572,27 @@ class ProjectApps(Controller):
                 is_succeed=response.is_succeed,
             )
         else:
-            self.app.render(
-                "No logs found in 1 minute",
-                renderer_type="text"
-            )
+            self.app.render("No logs found in 1 minute", renderer_type="text")
 
     @ex(
         help='Export Project App Logs',
         arguments=[
-            (['project_id'], {'help': 'Project ID', 'action': 'store', }),
+            (
+                ['project_id'],
+                {
+                    'help': 'Project ID',
+                    'action': 'store',
+                },
+            ),
             (['project_app_id'], {'help': 'Project App ID', 'action': 'store'}),
             (['-d', '--dates'], {'help': 'Dates (YYYY-MM-DD)', 'action': 'store', 'dest': 'dates', 'default': ''}),
             (['-p', '--process'], {'help': 'Process type', 'action': 'store', 'default': ''}),
-            (['-s', '--start_date'], {'help': 'Start date (YYYY-MM-DD HH:MM)', 'action': 'store', 'dest': 'start_date'}),
+            (
+                ['-s', '--start_date'],
+                {'help': 'Start date (YYYY-MM-DD HH:MM)', 'action': 'store', 'dest': 'start_date'},
+            ),
             (['-e', '--end_date'], {'help': 'End date (YYYY-MM-DD HH:MM)', 'action': 'store', 'dest': 'end_date'}),
-        ]
+        ],
     )
     def export_logs(self):
         project_id = self.app.pargs.project_id
@@ -494,7 +619,7 @@ class ProjectApps(Controller):
                 dates=dates,
                 applications=applications,
                 start_date=start_date,
-                end_date=end_date
+                end_date=end_date,
             )
         except AkinonCLIError as e:
             if e.response.status_code == 406:
@@ -515,14 +640,19 @@ class Addons(Controller):
     @ex(
         help='Addon List Command',
         arguments=[
-            (['project_id'], {'help': 'Project ID', 'action': 'store', }),
+            (
+                ['project_id'],
+                {
+                    'help': 'Project ID',
+                    'action': 'store',
+                },
+            ),
             (['project_app_id'], {'help': 'Project App ID', 'action': 'store'}),
         ],
     )
     def list(self):
         response = self.app.client.get_addons(
-            project_id=int(self.app.pargs.project_id),
-            project_app_id=int(self.app.pargs.project_app_id)
+            project_id=int(self.app.pargs.project_id), project_app_id=int(self.app.pargs.project_app_id)
         )
         self.app.render(
             data=response.data,
@@ -535,7 +665,7 @@ class Addons(Controller):
                 "config": "Config",
                 "remote_url": "Remote URL",
                 "status": "Status",
-                "is_provisioned": "Is Provisioned"
+                "is_provisioned": "Is Provisioned",
             },
-            is_succeed=response.is_succeed
+            is_succeed=response.is_succeed,
         )
