@@ -93,7 +93,7 @@ class AkinonOutputHandler(OutputHandler):
         "rich": RichRenderer,
         "realtime_log": RealtimeLogRenderer,
         "table": TableRenderer,
-        "pipeline_log": PipelineLogRenderer
+        "pipeline_log": PipelineLogRenderer,
     }
 
     class Meta:
